@@ -8,13 +8,14 @@
 
 ;; Maintainer: Mark A. Hershberger <mah@everybody.org>
 ;; Original Author: Daniel Lundin <daniel@codefactory.se>
-;; Version: 1.6.16
+;; Version: 1.6.17
 ;; Created: May 13 2001
-;; Keywords: xml rpc network
+;; Keywords: xml rpc network comm
+;; Package-Requires: ((emacs "24.1"))
 ;; URL: http://github.com/xml-rpc-el/xml-rpc-el
-;; Last Modified: <2022-10-04 18:14:42 skangas>
+;; Last Modified: <2023-10-09 10:56:07 skangas>
 
-(defconst xml-rpc-version "1.6.16"
+(defconst xml-rpc-version "1.6.17"
   "Current version of xml-rpc.el.")
 
 ;; This file is NOT (yet) part of GNU Emacs.
@@ -32,11 +33,12 @@
 ;; You should have received a copy of the GNU General Public License
 ;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+;;; Commentary:
+
 ;;; Code:
 
 (require 'xml)
 (require 'url-http)
-(require 'timezone)
 
 (defconst xml-rpc-maintainer-address "mah@everybody.org"
   "The address where bug reports should be sent.")
@@ -141,6 +143,8 @@ a list that is not datetime, base64 or struct."
 (defvar xml-rpc--date-parses-as nil)
 (defvar xml-rpc--tz-pd-defined-in nil)
 
+(autoload 'timezone-parse-date "timezone")
+
 (defun xml-rpc-submit-bug-report ()
  "Submit a bug report on xml-rpc."
  (interactive)
@@ -181,7 +185,7 @@ sequence, or it will be confused for a list."
   (and (listp value)
        (eq (car value) :base64)))
 
-(defsubst xml-rpc-valuep (value)
+(defun xml-rpc-valuep (value)
   "Return t if VALUE is any sort of xml-rpc structure.
 
 Return nil otherwise."
@@ -356,7 +360,7 @@ functions in xml.el."
 
 (defsubst xml-rpc-response-errorp (response)
   "An `xml-rpc-method-call' result value is always a list, where the first
-element in RESPONSE is either nil or if an error occured, a cons pair
+element in RESPONSE is either nil or if an error occurred, a cons pair
 according to (errnum . \"Error string\")."
   (eq 'fault (car-safe (caddar response))))
 
@@ -406,7 +410,7 @@ the parsed XML response is returned."
 
 If ASYNC-CALLBACK-FUNCTION is non-nil, the request will be performed
 asynchronously and ASYNC-CALLBACK-FUNCTION should be a callback function to
-be called when the reuest is finished.  ASYNC-CALLBACK-FUNCTION is called with
+be called when the request is finished.  ASYNC-CALLBACK-FUNCTION is called with
 a single argument being an xml.el style XML list.
 
 It returns an XML list containing the method response from the XML-RPC server,
@@ -460,7 +464,7 @@ or nil if called with ASYNC-CALLBACK-FUNCTION."
                  (if async-callback-function
                      (let ((cbargs (list async-callback-function)))
                        (url-retrieve server-url
-                                     'xml-new-rpc-request-callback-handler
+                                     'xml-rpc-new-request-callback-handler
                                      cbargs))
                    (let ((buffer (url-retrieve-synchronously server-url)))
                      (with-current-buffer buffer
@@ -504,7 +508,7 @@ or nil if called with ASYNC-CALLBACK-FUNCTION."
          ((listp elem)
           (setq result (append result (list (xml-rpc-clean elem)))))
 
-         ;; everthing else, as is.
+         ;; everything else, as is.
          (t
           (setq result (append result (list elem))))))
       result))
@@ -572,7 +576,7 @@ handled from XML-BUFFER."
     (funcall callback-fun (xml-rpc-xml-to-response xml-response))))
 
 
-(defun xml-new-rpc-request-callback-handler (_status callback-fun)
+(defun xml-rpc-new-request-callback-handler (_status callback-fun)
   "Handle a new style `url-retrieve' callback passing `STATUS'
 and `CALLBACK-FUN'."
   (let ((xml-buffer (current-buffer)))
@@ -609,6 +613,10 @@ parameters."
           (t
            (xml-rpc-xml-to-response response)))))
 
+;; This can be removed later:
+(define-obsolete-function-alias 'xml-new-rpc-request-callback-handler
+  #'xml-rpc-new-request-callback-handler "XML-RPC 1.6.15")
+
 (provide 'xml-rpc)
 
 ;; Local Variables:
